@@ -3,6 +3,7 @@ use v5.18;
 use utf8;
 
 use Moo;
+extends 'NewsExtractor::TXExtractor';
 
 use Encode qw(decode);
 use List::Util qw(max);
@@ -13,8 +14,6 @@ use Types::Standard qw(Str InstanceOf Maybe);
 use Importer 'NewsExtractor::TextUtil'  => qw( normalize_whitespace );
 use Importer 'NewsExtractor::Constants' => qw( %RE );
 
-has tx => ( required => 1, is => 'ro', isa => InstanceOf['Mojo::Transaction::HTTP'] );
-
 has site_name => (
     is => "lazy",
     isa => Maybe[Str],
@@ -22,27 +21,6 @@ has site_name => (
 
 no Moo;
 
-sub dom {
-    my $tx = $_[0]->tx;
-    my $dom = $tx->result->dom;
-
-    my $charset;
-    if ($tx->result->headers->content_type =~ /charset=(\S+)/) {
-        $charset = $1;
-    } elsif (my $el = $dom->at('meta[http-equiv="content-type" i]')) {
-        if ($el->attr("content") =~ /\;\s*charset=(\S+)/i) {
-            $charset = $1;
-        }
-    }
-
-    if ($charset) {
-        my $body = decode($charset, $tx->result->body);
-        $dom = Mojo::DOM->new($body);
-    }
-
-    return $dom;
-}
-
 sub _build_site_name {
     my ($self) = @_;
 
